@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_iam._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-cloudfront",
-    "1.62.0",
+    "1.65.0",
     __name__[0:-6],
-    "aws-cloudfront@1.62.0.jsii.tgz",
+    "aws-cloudfront@1.65.0.jsii.tgz",
 )
 
 __all__ = [
